# Copyright (c) 2000-2009, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define with()          %{expand:%%{?with_%{1}:1}%%{!?with_%{1}:0}}
%define without()       %{expand:%%{?with_%{1}:0}%%{!?with_%{1}:1}}
%define bcond_with()    %{expand:%%{?_with_%{1}:%%global with_%{1} 1}}
%define bcond_without() %{expand:%%{!?_without_%{1}:%%global with_%{1} 1}}

%bcond_with gcj_support
%bcond_with readline
%bcond_without servlet
%bcond_without repolib

%if %with gcj_support
%define gcj_support 1
%else
%define gcj_support 0
%endif

%define section free

%define repodir %{_javadir}/repository.jboss.com/beanshell/%{version}-brew
%define repodirlib %{repodir}/lib
%define repodirsrc %{repodir}/src

%define Name BeanShell
%define fversion 1.3.0

Name:           bsh
Version:        1.3.0
Release:        15.5.1%{?dist}
Epoch:          0
Summary:        Lightweight Scripting for Java
License:        LGPLv2+
Group:          Development/Java
URL:            http://www.beanshell.org/
Source0:        %{name}-%{fversion}-src.tar.bz2
#cvs -d:pserver:anonymous@beanshell.cvs.sourceforge.net:/cvsroot/beanshell login
#cvs -z3 -d:pserver:anonymous@beanshell.cvs.sourceforge.net:/cvsroot/beanshell export -r rel_1_3_0_final BeanShell
#tar cjf bsh-1.3.0-src.tar.bz2 BeanShell
Source1:        bsh-1.3.0.pom
Source2:        bsh-bsf-1.3.0.pom
Source3:        bsh-component-info.xml
Source4:	bsh-upload.sh
# http://repository.jboss.org/maven2-brew/org/beanshell/bsh/1.3.0/bsh-1.3.0.pom
Source5: 	bsh.pom
Source6:        %{name}-desktop.desktop
Patch0:         %{name}-build.patch
Patch1:         %{name}-readline.patch
Requires(post): jpackage-utils
Requires(postun): jpackage-utils
Requires:       bsf
Requires:       jpackage-utils
BuildRequires:  ImageMagick, desktop-file-utils
BuildRequires:  ant
BuildRequires:  ant-trax
BuildRequires:  bsf
BuildRequires:  java-devel
BuildRequires:  jpackage-utils
%if %with servlet
BuildRequires:  servlet_2_5_api
%endif
%if %with readline
BuildRequires:  libreadline-java
%endif
# To create content for maven2-brew 
BuildRequires:  maven-deploy-plugin
Buildarch:      noarch
%if %{gcj_support}
BuildRequires:  java-gcj-compat-devel
%else
Buildarch:      noarch
%endif
Buildroot:      %{_tmppath}/%{name}-%{version}-%{release}-root


%description
BeanShell is a small, free, embeddable, Java source interpreter with
object scripting language features, written in Java. BeanShell executes
standard Java statements and expressions, in addition to obvious
scripting commands and syntax. BeanShell supports scripted objects as
simple method closures like those in Perl and JavaScript(tm).
You can use BeanShell interactively for Java experimentation and
debugging or as a simple scripting engine for your applications. In
short: BeanShell is a dynamically interpreted Java, plus some useful
stuff. Another way to describe it is to say that in many ways BeanShell
is to Java as Tcl/Tk is to C: BeanShell is embeddable - You can call
BeanShell from your Java applications to execute Java code dynamically
at run-time or to provide scripting extensibility for your applications.
Alternatively, you can call your Java applications and objects from
BeanShell; working with Java objects and APIs dynamically. Since
BeanShell is written in Java and runs in the same space as your
application, you can freely pass references to "real live" objects into
scripts and return them as results.

%if %with repolib
%package repolib
Summary:         Artifacts to be uploaded to a repository library
Group:           Development/Libraries/Java

%description repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%package manual
Summary:        Manual for %{name}
Group:          Development/Java

%description manual
Documentation for %{name}.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Java

%description javadoc
Javadoc for %{name}.

%package demo
Summary:        Demo for %{name}
Group:          Development/Java
AutoReqProv:    no
Requires:       %{name} = %{epoch}:%{version}-%{release}
Requires:       /usr/bin/env

%description demo
Demonstrations and samples for %{name}.

%package desktop
Summary:        Desktop integration for %{name}
Group:          Development/Libraries
Requires:       %{name} = %{epoch}:%{version}-%{release}

%description desktop
Contains a menu entry for %{name}.

%prep
%setup -q -n BeanShell
%patch0 -p1
%if %with readline
%patch1 -p1
%endif
%{_bindir}/find -type f -name "*.jar" | %{_bindir}/xargs -t %{__rm}
# remove all CVS files
%{_bindir}/find -type d -name CVS | %{_bindir}/xargs -t %{__rm} -r
%{_bindir}/find -type f -name .cvsignore | %{_bindir}/xargs -t %{__rm}
%{__mkdir_p} lib
%if %with servlet
pushd lib
ln -sf $(build-classpath bsf)
ln -sf $(build-classpath servlet_2_5_api) servlet.jar
popd
%else
%{__rm} -r src/bsh/servlet
%endif

%build
export CLASSPATH=$(build-classpath bsf)
export OPT_JAR_LIST=`%{__cat} %{_sysconfdir}/ant.d/trax`
%{ant} dist
%if %without servlet
%{__rm} -r src/bsh/servlet
%{ant} -Dexclude-servlet='bsh/servlet/*' compile
%{ant} -Dexclude-servlet='bsh/servlet/*' jarall
%{ant} -Dexclude-servlet='bsh/servlet/*' javadoc
%{ant} -Dexclude-servlet='bsh/servlet/*' bshdoc
%else
%{ant} dist
%endif

%ifnarch ppc64 s390x
(cd docs/faq && %{ant})
(cd docs/manual && %{ant})
%endif

%install
rm -rf %{buildroot}

# jars
install -d -m 755 %{buildroot}%{_javadir}
install -p -m 644 dist/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}-%{version}.jar
install -p -m 644 dist/%{name}-bsf-%{version}.jar %{buildroot}%{_javadir}/%{name}-bsf-%{version}.jar
install -p -m 644 dist/%{name}-classpath-%{version}.jar %{buildroot}%{_javadir}/%{name}-classpath-%{version}.jar
install -p -m 644 dist/%{name}-commands-%{version}.jar %{buildroot}%{_javadir}/%{name}-commands-%{version}.jar
install -p -m 644 dist/%{name}-core-%{version}.jar %{buildroot}%{_javadir}/%{name}-core-%{version}.jar
install -p -m 644 dist/%{name}-reflect-%{version}.jar %{buildroot}%{_javadir}/%{name}-reflect-%{version}.jar
install -p -m 644 dist/%{name}-util-%{version}.jar %{buildroot}%{_javadir}/%{name}-util-%{version}.jar
(cd %{buildroot}%{_javadir} && for jar in *-%{version}*; do ln -sf ${jar} ${jar/-%{version}/}; done)

# poms
install -d -m 755 %{buildroot}%{_datadir}/maven2/poms
install -p -m 644 %{SOURCE1} %{buildroot}%{_datadir}/maven2/poms/JPP.%{name}.pom
install -p -m 644 %{SOURCE2} %{buildroot}%{_datadir}/maven2/poms/JPP.%{name}-bsf.pom
install -p -m 644 %{SOURCE5} %{buildroot}%{_datadir}/maven2/poms/%{name}.pom
%add_to_maven_depmap bsh %{name} %{version} JPP %{name}
%add_to_maven_depmap bsh %{name}-bsf %{version} JPP %{name}-bsf

# manual
# FIXME: (dwalluck): breaks -bi --short-circuit
find docs -name ".cvswrappers" -exec rm -f {} \;
find docs -name "*.xml" -exec rm -f {} \;
find docs -name "*.xsl" -exec rm -f {} \;
find docs -name "*.log" -exec rm -f {} \;
%ifnarch ppc64 s390x
(cd docs/manual && mv html/* . || :)
(cd docs/manual && rm -rf html)
(cd docs/manual && rm -rf xsl)
%endif
# javadoc
install -d -m 755 %{buildroot}%{_javadocdir}/%{name}-%{version}
cp -pr javadoc/* %{buildroot}%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} %{buildroot}%{_javadocdir}/%{name}
# menu entry
desktop-file-install --vendor=fedora --mode=644 \
  --dir=$RPM_BUILD_ROOT%{_datadir}/applications %{SOURCE6}
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/16x16/apps
convert src/bsh/util/lib/icon.gif \
  $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/16x16/apps/bsh.png

# demo
for i in `find tests -name \*.bsh`; do
  perl -p -i -e 's,^\n?#!(/(usr/)?bin/java bsh\.Interpreter|/bin/sh),#!/usr/bin/env %{_bindir}/%{name},' $i
  if head -1 $i | grep '#!/usr/bin/env %{_bindir}/%{name}' >/dev/null; then
    chmod 755 $i
  fi
done
chmod 755 tests/Template
cat > one << EOF
#!/bin/sh

EOF
cat tests/Interactive/reload/one >> one
cat one > tests/Interactive/reload/one
rm one
cat > two << EOF
#!/bin/sh

EOF
cat tests/Interactive/reload/two >> two
cat two > tests/Interactive/reload/two
rm two

install -d -m 755 %{buildroot}%{_datadir}/%{name}
cp -pr tests %{buildroot}%{_datadir}/%{name}

install -d -m 755 %{buildroot}%{_datadir}/%{name}/webapps
install -p -m 644 dist/bshservlet.war %{buildroot}%{_datadir}/%{name}/webapps
install -p -m 644 dist/bshservlet-wbsh.war %{buildroot}%{_datadir}/%{name}/webapps

# scripts
install -d %{buildroot}%{_bindir}

function bsh_script() {
cat > $RPM_BUILD_ROOT%{_bindir}/$1 << EOF
#!/bin/sh
#
# $1 script
# JPackage Project (http://jpackage.sourceforge.net)

# Source functions library
. %{_datadir}/java-utils/java-functions

# Source system prefs
if [ -f %{_sysconfdir}/%{name}.conf ] ; then
  . %{_sysconfdir}/%{name}.conf
fi

# Source user prefs
if [ -f \$HOME/.%{name}rc ] ; then
  . \$HOME/.%{name}rc
fi

# Configuration
MAIN_CLASS=$2
if [ -n "\$BSH_DEBUG" ]; then
  BASE_FLAGS=-Ddebug=true
fi

BASE_JARS="%{name}.jar"

%if %with readline
if [ -f %{libdir}/libJavaReadline.so ]; then
  BASE_FLAGS="$BASE_FLAGS -Djava.library.path=%{libdir}"
  BASE_FLAGS="\$BASE_FLAGS -Dbsh.console.readlinelib=GnuReadline"
  BASE_JARS="\$BASE_JARS libreadline-java.jar"
fi
%endif

# Set parameters
set_jvm
set_classpath \$BASE_JARS
set_flags \$BASE_FLAGS
set_options \$BASE_OPTIONS

# Let's start
run "\$@"
EOF
}

bsh_script bsh bsh.Interpreter
bsh_script bsh-desktop bsh.Console

cat > $RPM_BUILD_ROOT%{_bindir}/%{name}doc << EOF
#!/usr/bin/env %{_bindir}/%{name}
EOF
cat scripts/bshdoc.bsh >> %{buildroot}%{_bindir}/%{name}doc

%if %{gcj_support}
%{_bindir}/aot-compile-rpm \
   --exclude %{_datadir}/%{name}/webapps/bshservlet.war \
   --exclude %{_datadir}/%{name}/webapps/bshservlet-wbsh.war
%endif

%if %with repolib
install -d -m 755 %{buildroot}%{repodir}
install -d -m 755 %{buildroot}%{repodirlib}
install -p -m 644 %{SOURCE3} %{buildroot}%{repodir}/component-info.xml
sed -i 's/@VERSION@/%{version}.%{reltag}-brew/g' %{buildroot}%{repodir}/component-info.xml
tag=`echo %{name}-%{version}-%{release} | sed 's|\.|_|g'`
sed -i "s/@TAG@/$tag/g" %{buildroot}%{repodir}/component-info.xml
install -d -m 755 %{buildroot}%{repodirsrc}
install -p -m 644 %{PATCH0} %{buildroot}%{repodirsrc}
%if %with readline
install -p -m 644 %{PATCH1} %{buildroot}%{repodirsrc}
%endif
install -p -m 644 %{SOURCE0} %{buildroot}%{repodirsrc}
install -p -m 644 %{SOURCE1} %{buildroot}%{repodirsrc}
install -p -m 644 %{SOURCE2} %{buildroot}%{repodirsrc}
cp -p %{buildroot}%{_javadir}/bsh.jar %{buildroot}%{repodirlib}
cp -p %{buildroot}%{_datadir}/maven2/poms/bsh.pom %{buildroot}%{repodirlib}

install -p -m 755 %{SOURCE4} %{buildroot}%{repodir}/upload.sh
pushd %{buildroot}%{repodir}
./upload.sh %{buildroot}/usr/share/java/repository.jboss.com/maven2-brew/
popd

%endif

%clean
rm -rf %{buildroot}

%post
%update_maven_depmap
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%postun
%update_maven_depmap
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%files
%defattr(0644,root,root,0755)
%doc src/Changes.html src/License.txt src/README.txt
%attr(0755,root,root) %{_bindir}/%{name}
%attr(0755,root,root) %{_bindir}/%{name}doc
%{_javadir}*/%{name}-%{version}.jar
%{_javadir}*/%{name}.jar
%{_javadir}*/%{name}-bsf-%{version}.jar
%{_javadir}*/%{name}-bsf.jar
%{_javadir}*/%{name}-classpath-%{version}.jar
%{_javadir}*/%{name}-classpath.jar
%{_javadir}*/%{name}-commands-%{version}.jar
%{_javadir}*/%{name}-commands.jar
%{_javadir}*/%{name}-core-%{version}.jar
%{_javadir}*/%{name}-core.jar
%{_javadir}*/%{name}-reflect-%{version}.jar
%{_javadir}*/%{name}-reflect.jar
%{_javadir}*/%{name}-util-%{version}.jar
%{_javadir}*/%{name}-util.jar
%{_datadir}/maven2/poms/JPP.%{name}-bsf.pom
%{_datadir}/maven2/poms/JPP.%{name}.pom
%{_datadir}/maven2/poms/%{name}.pom
%{_mavendepmapfragdir}/%{name}
%dir %{_datadir}/%{name}
%if %{gcj_support}
%dir %{_libdir}/gcj/%{name}
%attr(-,root,root) %{_libdir}/gcj/%{name}/*
%endif

%ifnarch ppc64 s390x
%files manual
%defattr(0644,root,root,0755)
%doc docs/*
%endif

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}

%files demo
%defattr(-,root,root,0755)
%doc tests/README.txt tests/Interactive/README
%{_datadir}/%{name}/*

%if %with repolib
%files repolib
%defattr(0644,root,root,0755)
%{_javadir}*/repository.jboss.com
%endif

%files desktop
%defattr(-,root,root) 
%attr(0755,root,root) %{_bindir}/%{name}-desktop
%{_datadir}/applications/*%{name}-desktop.desktop
%{_datadir}/icons/hicolor/*x*/apps/%{name}.png

%changelog
* Mon Apr 25 2011 Yong Yang <yyang@redhat.com> - 0:1.3.0-15.5.1
- Merge with RHEL-6

* Thu Jan 27 2011 Fernando Nasser <fnasser@redhat.com> - 0:1.3.0-13.4
- Remove org.beanshell fragments, conflict with bsh2 used by maven

* Thu Jan 27 2011 Fernando Nasser <fnasser@redhat.com> - 0:1.3.0-13.3
- Add fragments for the org.beanshell groupId

* Fri Jan 14 2011 Yiqiao Wang <yiwang@redhat.com> - 0:1.3.0-13.2.2.2
- Rebuild 

* Tue Nov 16 2010 Yiqiao Wang <yiwang@redhat.com> - 0:1.3.0-13.2.2.1.1
- Add the right bsh.pom to repolib/lib dir

* Tue Nov 16 2010 Yiqiao Wang <yiwang@redhat.com> - 0:1.3.0-13.2.2.1
- Build with Maven 2.2.1
- Add upload.sh to repolib
- Fix %%files for signed jars
- Add content of maven2-brew

* Mon Jun 07 2010 Martha Benitez <mbenitez@redhat.com> - 0:1.3.0-13.2.2
- Fix Release tag

* Fri May 14 2010 Martha Benitez <mbenitez@redhat.com> - 0:1.3.0-13.1.1
- rebuilt

* Tue Aug 18 2009 David Walluck <dwalluck@redhat.com> 0:1.3.0-13.1
- fix permissions

* Tue Aug 18 2009 David Walluck <dwalluck@redhat.com> 0:1.3.0-13
- fix component-info.xml

* Tue Aug 18 2009 David Walluck <dwalluck@redhat.com> 0:1.3.0-12
- BuildRequires: ant-trax

* Thu Jul 12 2007 Ralph Apel <r.apel at r-apel.de> 0:1.3.0-11jpp
- Fix aot build
- Add pom and depmap frags
- Restore all jars
- Add webapps

* Mon Jan 29 2007 Permaine Cheung <pcheung@redhat.com> 0:1.3.0-10jpp
- Removed unapplied patch and moved buildroot removal from prep to install,
  and other rpmlint cleanup

* Fri Aug 04 2006 Deepak Bhole <dbhole@redhat.com> 0:1.3.0-9jpp
- Added missing requirements

* Thu Jul 20 2006 Deepak Bhole <dbhole@redhat.com> 0:1.3.0-8jpp
- Add conditional native compilation.

* Thu May 04 2006 Ralph Apel <r.apel at r-apel.de> 0:1.3.0-7jpp
- First JPP-1.7 release

* Fri Aug 20 2004 Ralph Apel <r.apel at r-apel.de> 0:1.3.0-6jpp
- Build with ant-1.6.2

* Mon Jan 26 2004 David Walluck <david@anti-microsoft.org> 0:1.3.0-5jpp
- really drop readline patch

* Sun Jan 25 2004 David Walluck <david@anti-microsoft.org> 0:1.3.0-4jpp
- drop readline patch

* Wed Jan 21 2004 David Walluck <david@anti-microsoft.org> 0:1.3.0-3jpp
- port libreadline-java patch to new bsh

* Tue Jan 20 2004 David Walluck <david@anti-microsoft.org> 0:1.3.0-2jpp
- add Distribution tag

* Tue Jan 20 2004 David Walluck <david@anti-microsoft.org> 0:1.3.0-1jpp
- 1.3.0
- remove bsf patch (fixed upstream)
- add epoch to demo package Requires

* Fri Apr 12 2003 David Walluck <david@anti-microsoft.org> 0:1.2-0.b8.4jpp
- fix strange permissions

* Fri Apr 11 2003 David Walluck <david@anti-microsoft.org> 0:1.2-0.b8.3jpp
- rebuild for JPackage 1.5
- add bsf patch

* Sat Feb 01 2003 David Walluck <david@anti-microsoft.org> 1.2-0.b8.2jpp
- remove servlet dependency (if anyone wants to add this as a separate
  package and do the tomcat integration, be my guest)

* Thu Jan 23 2003 David Walluck <david@anti-microsoft.org> 1.2-0.b8.1jpp
- rename to bsh
- add manual
- add Changes.html to %%doc
- add bsh and bshdoc scripts
- add %%dir %%{_datadir}/%%{name} to main package
- correct test interpreter and make bsh files executable

* Mon Jan 21 2002 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.01-3jpp
- really section macro

* Sun Jan 20 2002 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.01-2jpp
- additional sources in individual archives
- versioned dir for javadoc
- no dependencies for javadoc package
- stricter dependency for demo package
- section macro

* Tue Dec 18 2001 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.01-1jpp
- first JPackage release
